@@ -1,6 +1,6 @@
 /*
  *	psMalloc.h
- *	Release $Name: MATRIXSSL_1_2_5_OPEN $
+ *	Release $Name: MATRIXSSL_1_7_3_OPEN $
  *	
  *	Header for psMalloc functions
  */
@@ -10,7 +10,8 @@
  *
  *	This software is open source; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation version 2.
+ *	the Free Software Foundation; either version 2 of the License, or
+ *	(at your option) any later version.
  *
  *	This General Public License does NOT permit incorporating this software 
  *	into proprietary programs.  If you are unable to comply with the GPL, a 
@@ -31,6 +32,17 @@
 #ifndef _h_PS_MALLOC
 #define _h_PS_MALLOC
 
+#define PEERSEC_BASE_POOL 0
+#define PEERSEC_NO_POOL	(void *)0x00001
+
+/******************************************************************************/
+/*
+	Because a set of public APIs are exposed here there is a dependence on
+	the package.  The config layer header must be parsed to determine what
+	defines are configured
+*/
+#include "../../matrixCommon.h"
+
 /*
 	Native memory routines
 */
@@ -47,3 +59,6 @@ typedef int32 psPool_t;
 
 #endif /* _h_PS_MALLOC */
 
+
+
+
