@@ -1,6 +1,6 @@
 /*
  *	vxworks.c
- *	Release $Name: MATRIXSSL_1_2_5_OPEN $
+ *	Release $Name: MATRIXSSL_1_7_3_OPEN $
  *
  *	VXWORKS compatibility layer
  *	Other UNIX like operating systems should also be able to use this
@@ -12,7 +12,8 @@
  *
  *	This software is open source; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation version 2.
+ *	the Free Software Foundation; either version 2 of the License, or
+ *	(at your option) any later version.
  *
  *	This General Public License does NOT permit incorporating this software 
  *	into proprietary programs.  If you are unable to comply with the GPL, a 
@@ -47,7 +48,7 @@ static sslTime_t	elapsedTime; 	/* Last elapsed time */
 /*
 	OS dependent Open.
  */
-int sslOpenOsdep()
+int sslOpenOsdep(void)
 {
 	tickspersec = sysClkRateGet();
 
@@ -59,7 +60,7 @@ int sslOpenOsdep()
 /*
 	sslClose
  */
-int sslCloseOsdep()
+int sslCloseOsdep(void)
 {
 	psCloseMalloc();
 	return 0;
@@ -80,7 +81,7 @@ int sslGetEntropy(unsigned char *bytes, int size)
 /*
 	debug break.
  */
-void sslBreak()
+void sslBreak(void)
 {
 	abort();
 }
